@@ -2,14 +2,12 @@ import hashlib
 import logging
 import math
 
-import numpy
-
 logging.basicConfig(level=logging.DEBUG)
 logg = logging.getLogger()
 
-
 # m = ceil((n * log(p)) / log(1 / pow(2, log(2))));
 
+
 class Bloom:
 
     def __init__(self, bits, rounds, hasher=None):
@@ -18,7 +16,7 @@ class Bloom:
         if self.bytes * 8 != self.bits:
             raise ValueError('Need byte boundary bit value')
         self.rounds = rounds
-        self.filter = numpy.zeros(self.bytes, dtype=numpy.uint8)
+        self.filter = [0] * self.bytes
         if hasher == None:
             logg.info('using default hasher (SHA256)')
             hasher = self.__hash
@@ -57,6 +55,10 @@ class Bloom:
             return True
 
 
+    def dump(self):
+        return self.filter
+
+
     def __hash(self, b, s):
        logg.debug('hashing {} {}'.format(b.hex(), s.hex()))
        h = hashlib.sha256()
